@@ -5,7 +5,9 @@
 #' @return 			A list of resulting data: the probability estimates for
 #' 					each pair in the design of randomness where estmates close
 #' 					to ~0.5 represent random assignment, then the entropy metric
-#' 					and the distance metric.
+#' 					the distance metric, the maximum eigenvalue of the allocation
+#' 					var-cov matrix (operator norm) and the squared Frobenius norm 
+#' 					(the sum of the squared eigenvalues)
 #' 
 #' @author Adam Kapelner
 #' @export
@@ -27,12 +29,20 @@ compute_randomization_metrics = function(designs){
 	.jcall(java_obj, "V", "compute")
 	
 	#harvest the data and return it as a list
-	p_hat_ijs = sapply(.jcall(java_obj, "[[D", "getPhats"), .jevalArray)
+	p_hat_ijs = .jcall(java_obj, "[[D", "getPhats", simplify = TRUE)
 	rand_entropy_metric = .jcall(java_obj, "D", "getRandEntropyMetric")
 	rand_norm_se_metric = .jcall(java_obj, "D", "getRandStdErrMetric")
+	
+	#for the maximum eigenvalue we need to transform the allocation vector to be in {-1, 1}
+	designs[designs == 0] = -1
+	#now take the eigendecomposition of the variance-covariance matrix of the allocations
+	e_d = eigen(var(t(designs)))	
+	
 	list(
 		p_hat_ijs = p_hat_ijs, 
 		rand_entropy_metric = rand_entropy_metric, 
-		rand_norm_se_metric = rand_norm_se_metric
+		rand_norm_se_metric = rand_norm_se_metric,
+		max_eigenval = max(e_d$values),
+		frob_norm_sqd = sum(e_d$values^2)
 	)
 }
\ No newline at end of file
